SystemWindowHeader class

Constructors

SystemWindowHeader({SystemWindowText? title, SystemWindowText? subTitle, SystemWindowButton? button, SystemWindowPadding? padding, ButtonPosition? buttonPosition, SystemWindowDecoration? decoration})

Properties

button ↔ SystemWindowButton?
getter/setter pair
buttonPosition ↔ ButtonPosition?
getter/setter pair
decoration ↔ SystemWindowDecoration?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
padding ↔ SystemWindowPadding?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subTitle ↔ SystemWindowText?
getter/setter pair
title ↔ SystemWindowText?
getter/setter pair

Methods

getMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited