SystemWindowPadding class

Constructors

SystemWindowPadding({int? left, int? right, int? top, int? bottom})

Properties

bottom ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
left ↔ int?
getter/setter pair
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ int?
getter/setter pair

Methods

getMap() → Map<String, int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

setSymmetricPadding(int vertical, int horizontal) → SystemWindowPadding