SystemWindowText class

Constructors

SystemWindowText({required String text, double? fontSize, FontWeight? fontWeight, Color? textColor, SystemWindowPadding? padding})

Properties

fontSize ↔ double?
getter/setter pair
fontWeight ↔ FontWeight?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
padding ↔ SystemWindowPadding?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair
textColor ↔ Color?
getter/setter pair

Methods

getMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited