Commons class

Constructors

Commons()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

flagsToJson(List<SystemWindowFlags> flags) → List<String>
flagToJson(SystemWindowFlags flag) → String
getSystemWindowPrefMode(SystemWindowPrefMode prefMode) → String
Converts SystemWindowPrefMode to string format
getWindowGravity(SystemWindowGravity gravity) → String
Converts SystemWindowGravity to string format